arq
===

|Build Status| |Coverage| |pypi| |license|

Job queues in python with asyncio, redis and msgpack.

See `documentation`_ for more details.

.. |Build Status| image:: https://travis-ci.org/samuelcolvin/arq.svg?branch=master
   :target: https://travis-ci.org/samuelcolvin/arq
.. |Coverage| image:: https://codecov.io/gh/samuelcolvin/arq/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/samuelcolvin/arq
.. |pypi| image:: https://img.shields.io/pypi/v/arq.svg
   :target: https://pypi.python.org/pypi/arq
.. |license| image:: https://img.shields.io/pypi/l/arq.svg
   :target: https://github.com/samuelcolvin/arq
.. _documentation: https://arq-docs.helpmanual.io/
